@@ -6,28 +6,28 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.211 qw(:Parse);
+use IO::Compress::Base::Common  2.214 qw(:Parse);
 
-use IO::Uncompress::Adapter::Inflate  2.211 ();
+use IO::Uncompress::Adapter::Inflate  2.214 ();
 
 
-use IO::Uncompress::Base  2.211 ;
-use IO::Uncompress::Gunzip  2.211 ;
-use IO::Uncompress::Inflate  2.211 ;
-use IO::Uncompress::RawInflate  2.211 ;
-use IO::Uncompress::Unzip  2.211 ;
+use IO::Uncompress::Base  2.214 ;
+use IO::Uncompress::Gunzip  2.214 ;
+use IO::Uncompress::Inflate  2.214 ;
+use IO::Uncompress::RawInflate  2.214 ;
+use IO::Uncompress::Unzip  2.214 ;
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyInflateError);
 
-$VERSION = '2.211';
+$VERSION = '2.214';
 $AnyInflateError = '';
 
 @ISA = qw(IO::Uncompress::Base Exporter);
 @EXPORT_OK = qw( $AnyInflateError anyinflate ) ;
 %EXPORT_TAGS = %IO::Uncompress::Base::DEFLATE_CONSTANTS if keys %IO::Uncompress::Base::DEFLATE_CONSTANTS;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 Exporter::export_ok_tags('all');
 
 # TODO - allow the user to pick a set of the three formats to allow
@@ -1014,7 +1014,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2025 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
